@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant
 #ifndef QV4COMPILEDDATA_P_H
 #define QV4COMPILEDDATA_P_H
 
@@ -51,7 +52,7 @@ QT_BEGIN_NAMESPACE
 // Also change the comment behind the number to describe the latest change. This has the added
 // benefit that if another patch changes the version too, it will result in a merge conflict, and
 // not get removed silently.
-#define QV4_DATA_STRUCTURE_VERSION 0x47 // Removed various counts
+#define QV4_DATA_STRUCTURE_VERSION 0x48 // Hotfix 6.10 - meta object change
 
 class QIODevice;
 class QQmlTypeNameCache;
@@ -821,7 +822,7 @@ public:
     }
 
     CommonType commonType() const {
-        if (data.get<IsCommonTypeField>() != 0)
+        if (isCommonType())
             return CommonType(data.get<CommonTypeOrTypeNameIndexField>());
         return CommonType::Invalid;
     }
