@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:critical reason:data-parser
 
 #ifndef QQMLJSKEYWORDS_P_H
 #define QQMLJSKEYWORDS_P_H
@@ -521,6 +522,11 @@ static inline int classify7(QStringView s, int parseModeFlags) {
       }
     }
   }
+  else if ((parseModeFlags & Lexer::QmlMode) && s[0].unicode() == 'v') {
+      if (s.slice(1) == QLatin1StringView("irtual")) {
+          return Lexer::T_VIRTUAL;
+      }
+  }
   return Lexer::T_IDENTIFIER;
 }
 
@@ -593,6 +599,11 @@ static inline int classify8(QStringView s, int parseModeFlags) {
       }
     }
   }
+  else if ((parseModeFlags & Lexer::QmlMode) && s[0].unicode() == 'o') {
+      if (s.slice(1) == QLatin1StringView("verride")) {
+          return Lexer::T_OVERRIDE;
+      }
+  }
   else if ((parseModeFlags & Lexer::QmlMode) && s[0].unicode() == 'p') {
     if (s[1].unicode() == 'r') {
       if (s[2].unicode() == 'o') {
