@@ -44,7 +44,9 @@ tst_qmlls_modules::tst_qmlls_modules() : QQmlDataTest(QT_QMLTEST_DATADIR)
     qputenv("QT_LOGGING_RULES", "*.debug=true;*.warning=true");
     // when using EditingRecorder
     m_server.setProgram(m_qmllsPath);
-    // m_server.setArguments(QStringList() << u"-v"_s << u"-w"_s << u"7"_s);
+    m_server.setArguments(QStringList{
+            "--no-cmake-calls"_L1,
+    });
 }
 
 void tst_qmlls_modules::init()
@@ -787,6 +789,7 @@ void tst_qmlls_modules::documentFormatting_data()
     excludedFiles << u"tests/auto/qml/qmlformat/data/normalizedFunctionsSpacing.qml"_s;
     excludedFiles << u"tests/auto/qml/qmlformat/data/normalizedObjectsSpacing.qml"_s;
     excludedFiles << u"tests/auto/qml/qmlformat/data/sortingImports.qml"_s;
+    excludedFiles << u"tests/auto/qml/qmlformat/data/normalizedGroupAttributesTogether.qml"_s;
 
     // excluded because it crashes Dom construction
     // TODO: fix QQMLDomAstConstructor to not crash on these files, see QTBUG-116392
@@ -1306,9 +1309,9 @@ void tst_qmlls_modules::warnings_data()
             << u"warnings/InvalidImport.qml"_s
             << ExpectedWarnings{ {
                        u"Warnings occurred while importing module \"foobar\": [import]"_s,
-                       u"Failed to import foobar. Are your import paths set up properly? Did you build your project? If yes, did you set the \"QT_QML_GENERATE_QMLLS_INI\" CMake variable on your project to \"ON\"? [import]"_s,
+                       u"Failed to import foobar. Are your import paths set up properly? Did you build your project? [import]"_s,
                        u"Warnings occurred while importing module \"foobaz\": [import]"_s,
-                       u"Failed to import foobaz. Are your import paths set up properly? Did you build your project? If yes, did you set the \"QT_QML_GENERATE_QMLLS_INI\" CMake variable on your project to \"ON\"? [import]"_s,
+                       u"Failed to import foobaz. Are your import paths set up properly? Did you build your project? [import]"_s,
                } };
 
     QTest::addRow("WithoutQmllsBuildIni")
@@ -1316,8 +1319,7 @@ void tst_qmlls_modules::warnings_data()
             << ExpectedWarnings{
                    { "Warnings occurred while importing module \"MyModule\": [import]"_L1,
                      "Failed to import MyModule. Are your import paths set up properly? Did you "
-                     "build your project? If yes, did you set the \"QT_QML_GENERATE_QMLLS_INI\" "
-                     "CMake variable on your project to \"ON\"? [import]"_L1,
+                     "build your project? [import]"_L1,
                      "MyComponent was not found. Did you add all imports and dependencies?: Did "
                      "you mean \"Component\"? [import]"_L1 }
                };
@@ -1379,8 +1381,7 @@ void tst_qmlls_modules::warnings_data()
                 "Warnings occurred while importing module \"MyModule\": [import]"_L1);
         missingWorkspaceB.warnings.append(
                 "Failed to import MyModule. Are your import paths set up properly? Did you build "
-                "your project? If yes, did you set the \"QT_QML_GENERATE_QMLLS_INI\" CMake "
-                "variable on your project to \"ON\"? [import]"_L1);
+                "your project? [import]"_L1);
         missingWorkspaceB.warnings.append(
                 "MyItem was not found. Did you add all imports and dependencies?: Did you mean \"Item\"? [import]"_L1);
         missingWorkspaceB.warnings.append(
@@ -1411,8 +1412,7 @@ void tst_qmlls_modules::warnings_data()
                 "Warnings occurred while importing module \"MyModule\": [import]"_L1);
         nestedWorkspaces.warnings.append(
                 "Failed to import MyModule. Are your import paths set up properly? Did you build "
-                "your project? If yes, did you set the \"QT_QML_GENERATE_QMLLS_INI\" CMake "
-                "variable on your project to \"ON\"? [import]"_L1);
+                "your project? [import]"_L1);
         nestedWorkspaces.warnings.append(
                 "MyItem was not found. Did you add all imports and dependencies?: Did you mean \"Item\"? [import]"_L1);
         nestedWorkspaces.warnings.append(
@@ -1642,11 +1642,35 @@ void tst_qmlls_modules::hover_data()
     QTest::addColumn<QLspSpecification::Position>("hoveredPosition");
     QTest::addColumn<QLspSpecification::MarkupContent>("expectedResult");
 
-    const QString filePath = u"hover/test.qml"_s;
     {
+        const QString filePath = u"hover/test.qml"_s;
         QLspSpecification::MarkupContent content{ MarkupKind::PlainText, "should fail" };
+        // note: this test fails if you have built the qttools help engine plugin (the CI doesn't seem to build it)
         QTest::addRow("hover") << filePath << QLspSpecification::Position{ 7, 24 } << content;
     }
+
+    {
+        const QString filePath = u"hover/importpaths.qml"_s;
+        const QLspSpecification::MarkupContent expected{
+            MarkupKind::Markdown,
+            R"(Library at path %1/QtQuick/qmldir
+
+Import paths:
+
+ * %1)"_L1.arg(QLibraryInfo::path(QLibraryInfo::QmlImportsPath))
+                    .toUtf8(),
+        };
+        QTest::addRow("importpaths-no-version")
+                << filePath << QLspSpecification::Position{ 3, 11 } << expected;
+        QTest::addRow("importpaths2-no-version")
+                << filePath << QLspSpecification::Position{ 3, 3 } << expected;
+        QTest::addRow("importpaths-major-version")
+                << filePath << QLspSpecification::Position{ 4, 15 } << expected;
+        QTest::addRow("importpaths-minor-version")
+                << filePath << QLspSpecification::Position{ 4, 18 } << expected;
+        QTest::addRow("importpaths-with-version")
+                << filePath << QLspSpecification::Position{ 5, 11 } << expected;
+    }
 }
 
 void tst_qmlls_modules::hover()
@@ -1716,18 +1740,17 @@ void tst_qmlls_modules::qmldirImports()
     QFETCH(int, character);
     QFETCH(QString, expectedCompletion);
 
-    const auto uri = openFile(filePath);
-    QVERIFY(uri);
-
     if (addBuildDirectory == AddBuildDir) {
         Notifications::AddBuildDirsParams bDirs;
         UriToBuildDirs ub;
-        ub.baseUri = *uri;
         ub.buildDirs.append(testFile("buildDir").toUtf8());
         bDirs.buildDirsToSet.append(ub);
         m_protocol->typedRpc()->sendNotification(QByteArray(Notifications::AddBuildDirsMethod), bDirs);
     }
 
+    const auto uri = openFile(filePath);
+    QVERIFY(uri);
+
     bool diagnosticOk = false;
     bool completionOk = false;
     m_protocol->registerPublishDiagnosticsNotificationHandler(
@@ -1762,7 +1785,7 @@ void tst_qmlls_modules::qmldirImports()
         completionOk = true;
     });
 
-    QTRY_VERIFY_WITH_TIMEOUT(diagnosticOk && completionOk, 5000);
+    QTRY_VERIFY_WITH_TIMEOUT(diagnosticOk && completionOk, 10000);
 }
 
 void tst_qmlls_modules::quickFixes_data()
@@ -1922,8 +1945,8 @@ void tst_qmlls_modules::semanticHighlightingFull()
 {
     QFETCH(QString, filePath);
     const auto item = fileObject(testFile(filePath));
-    Highlights highlights;
-    const auto expectedData = HighlightingUtils::collectTokens(item, std::nullopt);
+    QmlHighlighting::HighlightsContainer highlights;
+    const auto expectedData = QmlHighlighting::Utils::collectTokens(item, std::nullopt);
 
     const auto uri = openFile(filePath);
     QVERIFY(uri);
@@ -1965,12 +1988,13 @@ void tst_qmlls_modules::semanticHighlightingRange()
     QFETCH(QLspSpecification::Range, range);
 
     const auto item = fileObject(testFile(filePath));
-    Highlights highlights;
+    QmlHighlighting::HighlightsContainer highlights;
     const auto qmlFile = item.as<QQmlJS::Dom::QmlFile>();
     const auto code = qmlFile->code();
     const int startOffset = int(QQmlLSUtils::textOffsetFrom(code, range.start.line, range.end.character));
     const int endOffset = int(QQmlLSUtils::textOffsetFrom(code, range.end.line, range.end.character));
-    const auto expectedData = HighlightingUtils::collectTokens(item, HighlightsRange{startOffset, endOffset});
+    const auto expectedData = QmlHighlighting::Utils::collectTokens(
+            item, QmlHighlighting::HighlightsRange{ startOffset, endOffset });
 
     const auto uri = openFile(filePath);
     QVERIFY(uri);
@@ -2015,9 +2039,10 @@ void tst_qmlls_modules::semanticHighlightingDelta()
 
     const auto fileItem = fileObject(testFile(filePath));
     const auto deltaFileItem = fileObject(testFile(deltaFilePath));
-    auto fullDocumentSemanticTokensData = HighlightingUtils::collectTokens(fileItem, std::nullopt);
-    auto editedDocumentSemanticTokensData = HighlightingUtils::collectTokens(deltaFileItem, std::nullopt);
-    const auto expectedEdits = HighlightingUtils::computeDiff(fullDocumentSemanticTokensData, editedDocumentSemanticTokensData);
+    auto fullDocumentSemanticTokensData = QmlHighlighting::Utils::collectTokens(fileItem, std::nullopt);
+    auto editedDocumentSemanticTokensData = QmlHighlighting::Utils::collectTokens(deltaFileItem, std::nullopt);
+    const auto expectedEdits = QmlHighlighting::Utils::computeDiff(
+            fullDocumentSemanticTokensData, editedDocumentSemanticTokensData);
 
     const auto uri = openFile(filePath);
     QVERIFY(uri);
