@@ -31,6 +31,7 @@ private slots:
     void fileNamesToWatch();
     void findFilePathsFromFileNames_data();
     void findFilePathsFromFileNames();
+    void openFiles_data();
     void openFiles();
     void importPathViaSettings();
     void reloadLotsOfFiles();
@@ -46,7 +47,14 @@ private slots:
     void duplicateWorkspace();
     void withQmllsBuildIni();
     void withQmllsBuildIniWithoutRootUrls();
+    void withQmllsBuildIniRelativeImportPath();
+    void withQmllsIniRelativeImportPath();
     void shortestRootUrlForFile();
+    void qprocessScheduler_data();
+    void qprocessScheduler();
+    void qprocessSchedulerProcess();
+    void multipleQProcessScheduler_data();
+    void multipleQProcessScheduler();
 };
 
 #endif // TST_QMLLS_QQMLCODEMODEL_H
